@@ -1,11 +1,11 @@
 // Symphonia
-// Copyright (c) 2019-2021 The Project Symphonia Developers.
+// Copyright (c) 2019-2022 The Project Symphonia Developers.
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
-use symphonia_core::errors::{Result, decode_error};
+use symphonia_core::errors::{decode_error, Result};
 use symphonia_core::io::ReadBytes;
 
 use crate::atoms::{Atom, AtomHeader};
@@ -26,7 +26,7 @@ impl Atom for FtypAtom {
         if header.data_len & 0x3 != 0 {
             return decode_error("isomp4: invalid ftyp data length");
         }
-    
+
         // Major
         let major = FourCc::new(reader.read_quad_bytes()?);
 
@@ -49,5 +49,4 @@ impl Atom for FtypAtom {
     fn header(&self) -> AtomHeader {
         self.header
     }
-    
 }
