@@ -1,20 +1,22 @@
 // Symphonia
-// Copyright (c) 2019-2021 The Project Symphonia Developers.
+// Copyright (c) 2019-2022 The Project Symphonia Developers.
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
-use symphonia_core::errors::{Result, decode_error};
-use symphonia_core::io::{ReadBytes, BufReader};
-use symphonia_core::util::bits;
-use symphonia_core::meta::{MetadataRevision, MetadataBuilder, StandardTagKey, StandardVisualKey, Tag};
+use symphonia_core::errors::{decode_error, Result};
+use symphonia_core::io::{BufReader, ReadBytes};
+use symphonia_core::meta::{
+    MetadataBuilder, MetadataRevision, StandardTagKey, StandardVisualKey, Tag,
+};
 use symphonia_core::meta::{Value, Visual};
+use symphonia_core::util::bits;
 use symphonia_metadata::{id3v1, itunes};
 
 use crate::atoms::{Atom, AtomHeader, AtomIterator, AtomType};
 
-use encoding_rs::{UTF_16BE, SHIFT_JIS};
+use encoding_rs::{SHIFT_JIS, UTF_16BE};
 use log::warn;
 
 /// Data type enumeration for metadata value atoms as defined in the QuickTime File Format standard.
@@ -79,7 +81,7 @@ impl From<u32> for DataType {
             77 => DataType::UnsignedInt32,
             78 => DataType::UnsignedInt64,
             79 => DataType::AffineTransformF64,
-            _  => DataType::Unknown(value),
+            _ => DataType::Unknown(value),
         }
     }
 }
@@ -115,7 +117,7 @@ fn parse_signed_int8(data: &[u8]) -> Option<Value> {
             let s = bits::sign_extend_leq8_to_i8(data[0], 8);
             Some(Value::from(s))
         }
-        _ => None
+        _ => None,
     }
 }
 
@@ -126,7 +128,7 @@ fn parse_signed_int16(data: &[u8]) -> Option<Value> {
             let s = bits::sign_extend_leq16_to_i16(u, 16);
             Some(Value::from(s))
         }
-        _ => None
+        _ => None,
     }
 }
 
@@ -137,7 +139,7 @@ fn parse_signed_int32(data: &[u8]) -> Option<Value> {
             let s = bits::sign_extend_leq32_to_i32(u, 32);
             Some(Value::from(s))
         }
-        _ => None
+        _ => None,
     }
 }
 
@@ -148,7 +150,7 @@ fn parse_signed_int64(data: &[u8]) -> Option<Value> {
             let s = bits::sign_extend_leq64_to_i64(u, 64);
             Some(Value::from(s))
         }
-        _ => None
+        _ => None,
     }
 }
 
@@ -164,7 +166,7 @@ fn parse_var_signed_int(data: &[u8]) -> Option<Value> {
 fn parse_unsigned_int8(data: &[u8]) -> Option<Value> {
     match data.len() {
         1 => Some(Value::from(data[0])),
-        _ => None
+        _ => None,
     }
 }
 
@@ -174,7 +176,7 @@ fn parse_unsigned_int16(data: &[u8]) -> Option<Value> {
             let u = BufReader::new(data).read_be_u16().ok()?;
             Some(Value::from(u))
         }
-        _ => None
+        _ => None,
     }
 }
 
@@ -184,7 +186,7 @@ fn parse_unsigned_int32(data: &[u8]) -> Option<Value> {
             let u = BufReader::new(data).read_be_u32().ok()?;
             Some(Value::from(u))
         }
-        _ => None
+        _ => None,
     }
 }
 
@@ -194,7 +196,7 @@ fn parse_unsigned_int64(data: &[u8]) -> Option<Value> {
             let u = BufReader::new(data).read_be_u64().ok()?;
             Some(Value::from(u))
         }
-        _ => None
+        _ => None,
     }
 }
 
@@ -213,7 +215,7 @@ fn parse_float32(data: &[u8]) -> Option<Value> {
             let f = BufReader::new(data).read_be_f32().ok()?;
             Some(Value::Float(f64::from(f)))
         }
-        _ => None
+        _ => None,
     }
 }
 
@@ -223,7 +225,7 @@ fn parse_float64(data: &[u8]) -> Option<Value> {
             let f = BufReader::new(data).read_be_f64().ok()?;
             Some(Value::Float(f))
         }
-        _ => None
+        _ => None,
     }
 }
 
@@ -256,7 +258,6 @@ fn add_generic_tag<B: ReadBytes>(
     builder: &mut MetadataBuilder,
     std_key: Option<StandardTagKey>,
 ) -> Result<()> {
-
     let tag = iter.read_atom::<MetaTagAtom>()?;
 
     for value_atom in tag.values.iter() {
@@ -277,7 +278,6 @@ fn add_var_unsigned_int_tag<B: ReadBytes>(
     builder: &mut MetadataBuilder,
     std_key: StandardTagKey,
 ) -> Result<()> {
-
     let tag = iter.read_atom::<MetaTagAtom>()?;
 
     if let Some(value_atom) = tag.values.first() {
@@ -297,7 +297,6 @@ fn add_var_signed_int_tag<B: ReadBytes>(
     builder: &mut MetadataBuilder,
     std_key: StandardTagKey,
 ) -> Result<()> {
-
     let tag = iter.read_atom::<MetaTagAtom>()?;
 
     if let Some(value_atom) = tag.values.first() {
@@ -317,7 +316,6 @@ fn add_boolean_tag<B: ReadBytes>(
     builder: &mut MetadataBuilder,
     std_key: StandardTagKey,
 ) -> Result<()> {
-
     let tag = iter.read_atom::<MetaTagAtom>()?;
 
     // There should only be 1 value.
@@ -339,7 +337,6 @@ fn add_m_of_n_tag<B: ReadBytes>(
     m_key: StandardTagKey,
     n_key: StandardTagKey,
 ) -> Result<()> {
-
     let tag = iter.read_atom::<MetaTagAtom>()?;
 
     // There should only be 1 value.
@@ -362,15 +359,14 @@ fn add_visual_tag<B: ReadBytes>(
     iter: &mut AtomIterator<B>,
     builder: &mut MetadataBuilder,
 ) -> Result<()> {
-
     let tag = iter.read_atom::<MetaTagAtom>()?;
 
     // There could be more than one attached image.
     for value in tag.values {
         let media_type = match value.data_type {
-            DataType::Bmp  => "image/bmp",
+            DataType::Bmp => "image/bmp",
             DataType::Jpeg => "image/jpeg",
-            DataType::Png  => "image/png",
+            DataType::Png => "image/png",
             _ => "",
         };
 
@@ -405,24 +401,22 @@ fn add_media_type_tag<B: ReadBytes>(
     if let Some(value) = tag.values.first() {
         if let Some(media_type_value) = value.data.get(0) {
             let media_type = match media_type_value {
-                0  => "Movie",
-                1  => "Normal",
-                2  => "Audio Book",
-                5  => "Whacked Bookmark",
-                6  => "Music Video",
-                9  => "Short Film",
+                0 => "Movie",
+                1 => "Normal",
+                2 => "Audio Book",
+                5 => "Whacked Bookmark",
+                6 => "Music Video",
+                9 => "Short Film",
                 10 => "TV Show",
                 11 => "Booklet",
-                _  => "Unknown",
+                _ => "Unknown",
             };
 
-            builder.add_tag(
-                Tag::new(
-                    Some(StandardTagKey::MediaFormat),
-                    "",
-                    Value::from(media_type)
-                )
-            );
+            builder.add_tag(Tag::new(
+                Some(StandardTagKey::MediaFormat),
+                "",
+                Value::from(media_type),
+            ));
         }
     }
 
@@ -433,7 +427,6 @@ fn add_id3v1_genre_tag<B: ReadBytes>(
     iter: &mut AtomIterator<B>,
     builder: &mut MetadataBuilder,
 ) -> Result<()> {
-
     let tag = iter.read_atom::<MetaTagAtom>()?;
 
     // There should only be 1 value.
@@ -444,9 +437,7 @@ fn add_id3v1_genre_tag<B: ReadBytes>(
         // The stored index uses 1-based indexing, but the ID3v1 genre list is 0-based.
         if index > 0 {
             if let Some(genre) = id3v1::util::genre_name((index - 1) as u8) {
-                builder.add_tag(
-                    Tag::new(Some(StandardTagKey::Genre), "", Value::from(*genre))
-                );
+                builder.add_tag(Tag::new(Some(StandardTagKey::Genre), "", Value::from(*genre)));
             }
         }
     }
@@ -458,7 +449,6 @@ fn add_freeform_tag<B: ReadBytes>(
     iter: &mut AtomIterator<B>,
     builder: &mut MetadataBuilder,
 ) -> Result<()> {
-
     let tag = iter.read_atom::<MetaTagAtom>()?;
 
     // A user-defined tag should only have 1 value.
@@ -479,7 +469,6 @@ fn add_freeform_tag<B: ReadBytes>(
     }
 
     Ok(())
-
 }
 
 /// Metadata tag data atom.
@@ -517,15 +506,10 @@ impl Atom for MetaTagDataAtom {
 
         // The data payload is the remainder of the atom.
         // TODO: Apply a limit.
-        let data = reader.read_boxed_slice_exact(
-            (header.data_len - AtomHeader::EXTRA_DATA_SIZE - 4) as usize
-        )?;
+        let data = reader
+            .read_boxed_slice_exact((header.data_len - AtomHeader::EXTRA_DATA_SIZE - 4) as usize)?;
 
-        Ok(MetaTagDataAtom {
-            header,
-            data,
-            data_type,
-        })
+        Ok(MetaTagDataAtom { header, data, data_type })
     }
 }
 
@@ -545,17 +529,13 @@ impl Atom for MetaTagNamespaceAtom {
     fn read<B: ReadBytes>(reader: &mut B, header: AtomHeader) -> Result<Self> {
         let (_, _) = AtomHeader::read_extra(reader)?;
 
-        let buf = reader.read_boxed_slice_exact(
-            (header.data_len - AtomHeader::EXTRA_DATA_SIZE) as usize
-        )?;
+        let buf = reader
+            .read_boxed_slice_exact((header.data_len - AtomHeader::EXTRA_DATA_SIZE) as usize)?;
 
         // Do a lossy conversion because metadata should not prevent the demuxer from working.
         let value = String::from_utf8_lossy(&buf).to_string();
 
-        Ok(MetaTagNamespaceAtom {
-            header,
-            value,
-        })
+        Ok(MetaTagNamespaceAtom { header, value })
     }
 }
 
@@ -616,16 +596,11 @@ impl Atom for MetaTagAtom {
                 AtomType::MetaTagMeaning => {
                     mean = Some(iter.read_atom::<MetaTagNamespaceAtom>()?);
                 }
-                _ => ()
+                _ => (),
             }
         }
 
-        Ok(MetaTagAtom {
-            header,
-            values,
-            mean,
-            name,
-        })
+        Ok(MetaTagAtom { header, values, mean, name })
     }
 }
 
@@ -650,9 +625,7 @@ impl Atom for IlstAtom {
         while let Some(header) = iter.next()? {
             // Ignore standard atoms, check if other is a metadata atom.
             match &header.atype {
-                AtomType::AdvisoryTag => {
-                    add_advisory_tag(&mut iter, &mut mb)?
-                }
+                AtomType::AdvisoryTag => add_advisory_tag(&mut iter, &mut mb)?,
                 AtomType::AlbumArtistTag => {
                     add_generic_tag(&mut iter, &mut mb, Some(StandardTagKey::AlbumArtist))?
                 }
@@ -678,9 +651,7 @@ impl Atom for IlstAtom {
                 AtomType::CopyrightTag => {
                     add_generic_tag(&mut iter, &mut mb, Some(StandardTagKey::Copyright))?
                 }
-                AtomType::CoverTag => {
-                    add_visual_tag(&mut iter, &mut mb)?
-                }
+                AtomType::CoverTag => add_visual_tag(&mut iter, &mut mb)?,
                 AtomType::CustomGenreTag => {
                     add_generic_tag(&mut iter, &mut mb, Some(StandardTagKey::Genre))?
                 }
@@ -690,14 +661,12 @@ impl Atom for IlstAtom {
                 AtomType::DescriptionTag => {
                     add_generic_tag(&mut iter, &mut mb, Some(StandardTagKey::Description))?
                 }
-                AtomType::DiskNumberTag => {
-                    add_m_of_n_tag(
-                        &mut iter,
-                        &mut mb,
-                        StandardTagKey::DiscNumber,
-                        StandardTagKey::DiscTotal
-                    )?
-                }
+                AtomType::DiskNumberTag => add_m_of_n_tag(
+                    &mut iter,
+                    &mut mb,
+                    StandardTagKey::DiscNumber,
+                    StandardTagKey::DiscTotal,
+                )?,
                 AtomType::EncodedByTag => {
                     add_generic_tag(&mut iter, &mut mb, Some(StandardTagKey::EncodedBy))?
                 }
@@ -708,9 +677,7 @@ impl Atom for IlstAtom {
                     // TODO: Need standard tag key for gapless playback.
                     // add_boolean_tag(&mut iter, &mut mb, )?
                 }
-                AtomType::GenreTag => {
-                    add_id3v1_genre_tag(&mut iter, &mut mb)?
-                }
+                AtomType::GenreTag => add_id3v1_genre_tag(&mut iter, &mut mb)?,
                 AtomType::GroupingTag => {
                     add_generic_tag(&mut iter, &mut mb, Some(StandardTagKey::ContentGroup))?
                 }
@@ -727,9 +694,7 @@ impl Atom for IlstAtom {
                 AtomType::LyricsTag => {
                     add_generic_tag(&mut iter, &mut mb, Some(StandardTagKey::Lyrics))?
                 }
-                AtomType::MediaTypeTag => {
-                    add_media_type_tag(&mut iter, &mut mb)?
-                }
+                AtomType::MediaTypeTag => add_media_type_tag(&mut iter, &mut mb)?,
                 AtomType::OwnerTag => {
                     add_generic_tag(&mut iter, &mut mb, Some(StandardTagKey::Owner))?
                 }
@@ -760,14 +725,12 @@ impl Atom for IlstAtom {
                 AtomType::TempoTag => {
                     add_var_signed_int_tag(&mut iter, &mut mb, StandardTagKey::Bpm)?
                 }
-                AtomType::TrackNumberTag => {
-                    add_m_of_n_tag(
-                        &mut iter,
-                        &mut mb,
-                        StandardTagKey::TrackNumber,
-                        StandardTagKey::TrackTotal
-                    )?
-                }
+                AtomType::TrackNumberTag => add_m_of_n_tag(
+                    &mut iter,
+                    &mut mb,
+                    StandardTagKey::TrackNumber,
+                    StandardTagKey::TrackTotal,
+                )?,
                 AtomType::TrackTitleTag => {
                     add_generic_tag(&mut iter, &mut mb, Some(StandardTagKey::TrackTitle))?
                 }
@@ -794,9 +757,6 @@ impl Atom for IlstAtom {
             }
         }
 
-        Ok(IlstAtom {
-            header,
-            metadata: mb.metadata(),
-        })
+        Ok(IlstAtom { header, metadata: mb.metadata() })
     }
-}
\ No newline at end of file
+}
