@@ -1,5 +1,5 @@
 // Symphonia
-// Copyright (c) 2019-2021 The Project Symphonia Developers.
+// Copyright (c) 2019-2022 The Project Symphonia Developers.
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -37,7 +37,7 @@ impl Atom for UdtaAtom {
     #[allow(clippy::single_match)]
     fn read<B: ReadBytes>(reader: &mut B, header: AtomHeader) -> Result<Self> {
         let mut iter = AtomIterator::new(reader, header);
-        
+
         let mut meta = None;
 
         while let Some(header) = iter.next()? {
@@ -45,13 +45,10 @@ impl Atom for UdtaAtom {
                 AtomType::Meta => {
                     meta = Some(iter.read_atom::<MetaAtom>()?);
                 }
-                _ => ()
+                _ => (),
             }
         }
 
-        Ok(UdtaAtom {
-            header,
-            meta,
-        })
+        Ok(UdtaAtom { header, meta })
     }
-}
\ No newline at end of file
+}
