@@ -1,12 +1,12 @@
 // Symphonia
-// Copyright (c) 2019-2021 The Project Symphonia Developers.
+// Copyright (c) 2019-2022 The Project Symphonia Developers.
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
-use symphonia_core::errors::{Error, Result, decode_error};
+use symphonia_core::errors::{decode_error, Error, Result};
 
-use crate::atoms::{MoofAtom, MoovAtom, StcoAtom, Co64Atom, MvexAtom, stsz::SampleSize};
+use crate::atoms::{stsz::SampleSize, Co64Atom, MoofAtom, MoovAtom, MvexAtom, StcoAtom};
 
 use std::sync::Arc;
 
@@ -21,7 +21,7 @@ pub struct SampleTiming {
     pub dur: u32,
 }
 
-pub trait StreamSegment: Send {
+pub trait StreamSegment: Send + Sync {
     /// Gets the sequence number of this segment.
     fn sequence_num(&self) -> u32;
 
@@ -41,7 +41,12 @@ pub trait StreamSegment: Send {
 
     /// Get the byte position and length of the sample indicated by `sample_num` for track
     /// `track_num`.
-    fn sample_data(&self, track_num: u32, sample_num: u32, get_offset: bool) -> Result<SampleDataDesc>;
+    fn sample_data(
+        &self,
+        track_num: u32,
+        sample_num: u32,
+        get_offset: bool,
+    ) -> Result<SampleDataDesc>;
 }
 
 /// Track-to-stream sequencing information.
@@ -76,8 +81,10 @@ impl MoofSegment {
                     trun.total_sample_duration
                 }
                 else {
-                    let duration = traf.tfhd.default_sample_duration.unwrap_or(
-                        mvex.trexs[track_num].default_sample_duration);
+                    let duration = traf
+                        .tfhd
+                        .default_sample_duration
+                        .unwrap_or(mvex.trexs[track_num].default_sample_duration);
 
                     u64::from(trun.sample_count) * u64::from(duration)
                 }
@@ -100,7 +107,10 @@ impl StreamSegment for MoofSegment {
 
     fn sample_timing(&self, track_num: u32, sample_num: u32) -> Result<Option<SampleTiming>> {
         // Get the track fragment associated with track_num.
-        let traf = self.moof.trafs.get(track_num as usize)
+        let traf = self
+            .moof
+            .trafs
+            .get(track_num as usize)
             .ok_or(Error::DecodeError("invalid track index"))?;
 
         let mut sample_num_rel = sample_num - self.seq[track_num as usize].first_sample;
@@ -110,20 +120,22 @@ impl StreamSegment for MoofSegment {
             // If the sample is contained within the this track fragment run, calculate and return
             // the exact sample timestamp.
             if sample_num_rel < trun.sample_count {
-
                 let timing = if trun.is_sample_duration_present() {
                     // The size of the entire track fragment run is known.
-                    let ts = trun.sample_duration[..1 + sample_num_rel as usize].iter()
-                                                                       .map(|&s| u64::from(s))
-                                                                       .sum::<u64>();
+                    let ts = trun.sample_duration[..1 + sample_num_rel as usize]
+                        .iter()
+                        .map(|&s| u64::from(s))
+                        .sum::<u64>();
 
                     let dur = trun.sample_duration[sample_num_rel as usize];
 
                     SampleTiming { ts: trun_ts_offset + ts, dur }
                 }
                 else {
-                    let dur = traf.tfhd.default_sample_duration.unwrap_or(
-                        self.mvex.trexs[track_num as usize].default_sample_duration);
+                    let dur = traf
+                        .tfhd
+                        .default_sample_duration
+                        .unwrap_or(self.mvex.trexs[track_num as usize].default_sample_duration);
 
                     let ts = u64::from(sample_num_rel) * u64::from(dur);
 
@@ -138,8 +150,10 @@ impl StreamSegment for MoofSegment {
                 trun.total_sample_duration
             }
             else {
-                let duration = traf.tfhd.default_sample_duration.unwrap_or(
-                    self.mvex.trexs[track_num as usize].default_sample_duration);
+                let duration = traf
+                    .tfhd
+                    .default_sample_duration
+                    .unwrap_or(self.mvex.trexs[track_num as usize].default_sample_duration);
 
                 u64::from(trun.sample_count) * u64::from(duration)
             };
@@ -153,7 +167,10 @@ impl StreamSegment for MoofSegment {
 
     fn ts_sample(&self, track_num: u32, ts: u64) -> Result<Option<u32>> {
         // Get the track fragment associated with track_num.
-        let traf = self.moof.trafs.get(track_num as usize)
+        let traf = self
+            .moof
+            .trafs
+            .get(track_num as usize)
             .ok_or(Error::DecodeError("invalid track index"))?;
 
         let mut sample_num = self.seq[track_num as usize].first_sample;
@@ -165,8 +182,10 @@ impl StreamSegment for MoofSegment {
                 trun.total_sample_duration
             }
             else {
-                let duration = traf.tfhd.default_sample_duration.unwrap_or(
-                    self.mvex.trexs[track_num as usize].default_sample_duration);
+                let duration = traf
+                    .tfhd
+                    .default_sample_duration
+                    .unwrap_or(self.mvex.trexs[track_num as usize].default_sample_duration);
 
                 u64::from(trun.sample_count) * u64::from(duration)
             };
@@ -190,8 +209,10 @@ impl StreamSegment for MoofSegment {
                     // If the sample durations are not present, then get the sample duration from
                     // the track fragment header or track extends atom. Then, calculate the number
                     // of samples are needed to reach the desired timestamp.
-                    let duration = traf.tfhd.default_sample_duration.unwrap_or(
-                        self.mvex.trexs[track_num as usize].default_sample_duration);
+                    let duration = traf
+                        .tfhd
+                        .default_sample_duration
+                        .unwrap_or(self.mvex.trexs[track_num as usize].default_sample_duration);
 
                     sample_num += ((ts - ts_accum) / u64::from(duration)) as u32;
                 }
@@ -206,10 +227,18 @@ impl StreamSegment for MoofSegment {
         Ok(None)
     }
 
-    fn sample_data(&self, track_num: u32, sample_num: u32, get_offset: bool) -> Result<SampleDataDesc> {
+    fn sample_data(
+        &self,
+        track_num: u32,
+        sample_num: u32,
+        get_offset: bool,
+    ) -> Result<SampleDataDesc> {
         // Get the track fragment associated with track_num.
-        let traf = self.moof.trafs.get(track_num as usize)
-                                  .ok_or(Error::DecodeError("invalid track index"))?;
+        let traf = self
+            .moof
+            .trafs
+            .get(track_num as usize)
+            .ok_or(Error::DecodeError("invalid track index"))?;
 
         // If an explicit anchor-point is set, then use that for the position, otherwise use the
         // first-byte of the enclosing moof atom.
@@ -242,8 +271,9 @@ impl StreamSegment for MoofSegment {
                     trun.sample_size[sample_num_rel as usize]
                 }
                 else {
-                    traf.tfhd.default_sample_size.unwrap_or(
-                        self.mvex.trexs[track_num as usize].default_sample_size)
+                    traf.tfhd
+                        .default_sample_size
+                        .unwrap_or(self.mvex.trexs[track_num as usize].default_sample_size)
                 };
 
                 let offset = if get_offset {
@@ -268,8 +298,10 @@ impl StreamSegment for MoofSegment {
                 trun.total_sample_size
             }
             else {
-                let size = traf.tfhd.default_sample_size.unwrap_or(
-                    self.mvex.trexs[track_num as usize].default_sample_size);
+                let size = traf
+                    .tfhd
+                    .default_sample_size
+                    .unwrap_or(self.mvex.trexs[track_num as usize].default_sample_size);
 
                 u64::from(trun.sample_count) * u64::from(size)
             };
@@ -292,13 +324,10 @@ impl StreamSegment for MoofSegment {
     }
 }
 
-
-
-
 fn get_chunk_offset(
     stco: &Option<StcoAtom>,
     co64: &Option<Co64Atom>,
-    chunk: usize
+    chunk: usize,
 ) -> Result<Option<u64>> {
     // Get the offset from either the stco or co64 atoms.
     if let Some(stco) = stco.as_ref() {
@@ -344,8 +373,11 @@ impl StreamSegment for MoovSegment {
 
     fn sample_timing(&self, track_num: u32, sample_num: u32) -> Result<Option<SampleTiming>> {
         // Get the trak atom associated with track_num.
-        let trak = self.moov.traks.get(track_num as usize)
-                                  .ok_or(Error::DecodeError("invalid track index"))?;
+        let trak = self
+            .moov
+            .traks
+            .get(track_num as usize)
+            .ok_or(Error::DecodeError("invalid track index"))?;
 
         // Find the sample timing. Note, complexity of O(N).
         let timing = trak.mdia.minf.stbl.stts.find_timing_for_sample(sample_num);
@@ -360,17 +392,28 @@ impl StreamSegment for MoovSegment {
 
     fn ts_sample(&self, track_num: u32, ts: u64) -> Result<Option<u32>> {
         // Get the trak atom associated with track_num.
-        let trak = self.moov.traks.get(track_num as usize)
-                                  .ok_or(Error::DecodeError("invalid track index"))?;
+        let trak = self
+            .moov
+            .traks
+            .get(track_num as usize)
+            .ok_or(Error::DecodeError("invalid track index"))?;
 
         // Find the sample timestamp. Note, complexity of O(N).
         Ok(trak.mdia.minf.stbl.stts.find_sample_for_timestamp(ts))
     }
 
-    fn sample_data(&self, track_num: u32, sample_num: u32, get_offset: bool) -> Result<SampleDataDesc> {
+    fn sample_data(
+        &self,
+        track_num: u32,
+        sample_num: u32,
+        get_offset: bool,
+    ) -> Result<SampleDataDesc> {
         // Get the trak atom associated with track_num.
-        let trak = self.moov.traks.get(track_num as usize)
-                                  .ok_or(Error::DecodeError("invalid trak index"))?;
+        let trak = self
+            .moov
+            .traks
+            .get(track_num as usize)
+            .ok_or(Error::DecodeError("invalid trak index"))?;
 
         // Get the constituent tables.
         let stsz = &trak.mdia.minf.stbl.stsz;
@@ -379,8 +422,9 @@ impl StreamSegment for MoovSegment {
         let co64 = &trak.mdia.minf.stbl.co64;
 
         // Find the sample-to-chunk mapping. Note, complexity of O(log N).
-        let group = stsc.find_entry_for_sample(sample_num)
-                        .ok_or(Error::DecodeError("invalid sample index"))?;
+        let group = stsc
+            .find_entry_for_sample(sample_num)
+            .ok_or(Error::DecodeError("invalid sample index"))?;
 
         // Index of the sample relative to the chunk group.
         let sample_in_group = sample_num - group.first_sample;
@@ -449,4 +493,4 @@ impl StreamSegment for MoovSegment {
     fn track_ts_range(&self, track_num: u32) -> (u64, u64) {
         (0, self.moov.traks[track_num as usize].mdia.minf.stbl.stts.total_duration)
     }
-}
\ No newline at end of file
+}
